# Boolean

A binary (true or false) value

URI: http://www.w3.org/2001/XMLSchema#boolean

* [base](https://w3id.org/linkml/base): Bool


* [repr](https://w3id.org/linkml/repr): bool




## Identifier and Mapping Information


